@@ -36,8 +36,8 @@
 --      Salt Lake City, UT 84127-0511, USA.
 --
 --   $Author: jsedwards $
---   $Date: 2009-08-01 08:34:47 -0600 (Sat, 01 Aug 2009) $
---   $Revision: 4227 $
+--   $Date: 2009-09-20 12:55:11 -0600 (Sun, 20 Sep 2009) $
+--   $Revision: 4371 $
 --
 --   NOTE: Subversion does not support the Log keyword so I have removed the
 --   logs that were here when I was using CVS.  Use the "svn log" command to
@@ -303,6 +303,7 @@ void nwos_initialize_disk_io(AccessType type, const char* path)
     assert(nwos_private_path == NULL);   /* make sure this is only called once */
     assert(private_file_desc == 0);
     assert(public_file_desc == 0);
+    assert(modified == false);
 
     nwos_public_path = nwos_get_public_objects_path();
 
@@ -475,20 +476,17 @@ bool nwos_disk_io_is_compressed_file(void)
     return nwos_storage_index != NULL;
 }
 
-bool nwos_disk_has_been_modified(void)
-{
-    return modified;
-}
-
 
 /*********************************************/
 /* Function to terminate the disk I/O module */
+/* Returns true if disk was modified         */
 /*********************************************/
 
-void nwos_terminate_disk_io()
+bool nwos_terminate_disk_io()
 {
     uint8 buffer[FILE_BLOCK_SIZE];
     char log_msg[256];
+    bool disk_was_modified = false;
 
     if (modified)
     {
@@ -522,6 +520,9 @@ void nwos_terminate_disk_io()
 	    perror(nwos_private_path);
 	    exit(1);
 	}
+
+	modified = false;
+	disk_was_modified = true;
     }
     else
     {
@@ -543,6 +544,8 @@ void nwos_terminate_disk_io()
     }
 
     public_file_desc = 0;
+
+    return disk_was_modified;
 }
 
 
