@@ -36,8 +36,8 @@
 --      Salt Lake City, UT 84127-0511, USA.
 --
 --   $Author: jsedwards $
---   $Date: 2009-08-01 08:34:47 -0600 (Sat, 01 Aug 2009) $
---   $Revision: 4227 $
+--   $Date: 2009-09-20 12:55:11 -0600 (Sun, 20 Sep 2009) $
+--   $Revision: 4371 $
 --
 --   NOTE: Subversion does not support the Log keyword so I have removed the
 --   logs that were here when I was using CVS.  Use the "svn log" command to
@@ -436,7 +436,6 @@ extern bool  nwos_disk_io_is_read_only();
 extern bool  nwos_disk_io_is_read_write();
 extern bool  nwos_disk_io_is_public_only();
 extern bool  nwos_disk_io_is_compressed_file(void);
-extern bool  nwos_disk_has_been_modified(void);
 extern bool  nwos_archive_is_block_device(void);
 extern bool  nwos_archive_is_file(void);
 extern void  nwos_write_bit_map(int chunk_index, void* map);
@@ -444,7 +443,7 @@ extern void  nwos_read_bit_map(int chunk_index, void* map);
 extern void  nwos_read_chunk_info(void* chunk_info, size_t chunk_info_size_in_bytes);
 extern void  nwos_write_chunk_info(void* chunk_info, size_t chunk_info_size_in_bytes);
 extern void  nwos_write_empty_chunk();
-extern void  nwos_terminate_disk_io();
+extern bool  nwos_terminate_disk_io();          /* returns true if disk was modified */
 
 
 /* These are only here temorarily until the index junk can be eliminated */
