@@ -36,8 +36,8 @@
 #      Salt Lake City, UT 84127-0511, USA.
 #
 #   $Author: jsedwards $
-#   $Date: 2009-08-15 07:29:25 -0600 (Sat, 15 Aug 2009) $
-#   $Revision: 4336 $
+#   $Date: 2009-09-21 07:15:46 -0600 (Mon, 21 Sep 2009) $
+#   $Revision: 4374 $
 #
 #   NOTE: Subversion does not support the Log keyword so I have removed the
 #   logs that were here when I was using CVS.  Use the "svn log" command to
@@ -107,9 +107,9 @@ cat   x14680064   x14680064 >  x29360128
 echo "---------------"
 echo " prep disk..."
 echo "---------------"
-if ! $EXEC/src/apps/util/prep_disk; then
+if ! $EXEC/src/apps/util/prep_archive; then
    echo ""
-   echo "prep_disk failed"
+   echo "prep_archive failed"
    echo ""
    exit 1
 fi
@@ -290,13 +290,14 @@ sleep 2
 echo "--------------------------"
 echo " prep disk for restore..."
 echo "--------------------------"
-if ! $EXEC/src/apps/util/prep_disk --no-private; then
+if ! $EXEC/src/apps/util/prep_archive --no-private; then
    echo ""
-   echo "prep_disk --no-private failed"
+   echo "prep_archive --no-private failed"
    echo ""
    exit 1
 fi
 
+sleep 1
 
 echo "---------------------"
 echo " expand..."
@@ -308,17 +309,7 @@ if ! $EXEC/src/apps/util/restore_archive /tmp/objectify_test/patched-after; then
    exit 1
 fi
 
-
-
-if ! $EXEC/src/apps/file/export_file "*"; then
-   echo ""
-   echo "export_file failed"
-   echo ""
-   exit 1
-fi
-
-for file in ../*.[ch]; do diff -s $file .; done
-
+sleep 1
 
 echo "---------------------"
 echo " verify and remove..."
@@ -330,15 +321,29 @@ if ! $EXEC/src/apps/file/verify_file --remove-no-shred *; then
    exit 1
 fi
 
+sleep 1
+
+echo "-------------------------------"
+echo " verify the files are gone..."
+echo "-------------------------------"
+if  ls x*; then
+   echo ""
+   echo "files were not removed!"
+   echo ""
+   exit 1
+fi
+
+sleep 1
+
 
 
 echo "---------------------------"
 echo " prep a second archive..."
 echo "---------------------------"
 
-if ! $EXEC/src/apps/util/prep_disk --no-private /tmp/objectify_test/private2.obj; then
+if ! $EXEC/src/apps/util/prep_archive --no-private /tmp/objectify_test/private2.obj; then
    echo ""
-   echo "prep_disk failed"
+   echo "prep_archive failed"
    echo ""
    exit 1
 fi
@@ -394,9 +399,9 @@ echo "---------------------------"
 echo " prep a third archive..."
 echo "---------------------------"
 
-if ! $EXEC/src/apps/util/prep_disk --no-private /tmp/objectify_test/private3.obj; then
+if ! $EXEC/src/apps/util/prep_archive --no-private /tmp/objectify_test/private3.obj; then
    echo ""
-   echo "prep_disk failed"
+   echo "prep_archive failed"
    echo ""
    exit 1
 fi
@@ -452,9 +457,9 @@ echo "---------------------------"
 echo " prep a fourth archive..."
 echo "---------------------------"
 
-if ! $EXEC/src/apps/util/prep_disk /tmp/objectify_test/private4.obj; then
+if ! $EXEC/src/apps/util/prep_archive /tmp/objectify_test/private4.obj; then
    echo ""
-   echo "prep_disk failed"
+   echo "prep_archive failed"
    echo ""
    exit 1
 fi
@@ -514,6 +519,182 @@ if $EXEC/src/apps/util/sync_archive /tmp/objectify_test/private3.obj /tmp/object
 fi
 
 
+sleep 2
+
+echo "--------------------------------------------------"
+echo " sync with second archive when it is the same..."
+echo "--------------------------------------------------"
+if ! $EXEC/src/apps/util/sync_archive /tmp/objectify_test/private.obj /tmp/objectify_test/private2.obj; then
+   echo ""
+   echo "sync_archive failed"
+   echo ""
+   exit 1
+fi
+
+sleep 2
+
+
+echo "------------------------------------------"
+echo " export files from third archive..."
+echo "------------------------------------------"
+
+export OBJECTIFY_PRIVATE_PATH=/tmp/objectify_test/private3.obj
+
+if ! $EXEC/src/apps/file/export_file "*"; then
+   echo ""
+   echo "export_file failed"
+   echo ""
+   exit 1
+fi
+
+sleep 2
+
+
+
+echo "-----------------------------------------------"
+echo " add another password to original archive..."
+echo "-----------------------------------------------"
+export OBJECTIFY_PRIVATE_PATH=/tmp/objectify_test/private.obj
+export OBJECTIFY_TEST_ONLY_DO_NOT_USE="Diff Compressed Test Too"
+
+if ! $EXEC/src/apps/util/add_password; then
+   echo ""
+   echo "add_password failed"
+   echo ""
+   exit 1
+fi
+
+sleep 2
+
+echo "-------------------"
+echo " import_files..."
+echo "-------------------"
+if ! $EXEC/src/apps/file/import_file x1*; then
+   echo ""
+   echo "import_file failed"
+   echo ""
+   exit 1
+fi
+
+sleep 1
+
+if ! $EXEC/src/apps/file/import_file x2*; then
+   echo ""
+   echo "import_file failed"
+   echo ""
+   exit 1
+fi
+
+sleep 1
+
+if ! $EXEC/src/apps/file/import_file x3*; then
+   echo ""
+   echo "import_file failed"
+   echo ""
+   exit 1
+fi
+
+sleep 1
+
+if ! $EXEC/src/apps/file/import_file x4*; then
+   echo ""
+   echo "import_file failed"
+   echo ""
+   exit 1
+fi
+
+sleep 1
+
+
+echo "------------------------------"
+echo " sync with second archive..."
+echo "------------------------------"
+if ! $EXEC/src/apps/util/sync_archive /tmp/objectify_test/private2.obj; then
+   echo ""
+   echo "sync_archive failed"
+   echo ""
+   exit 1
+fi
+
+sleep 2
+
+
+echo "-----------------------"
+echo " import more files..."
+echo "-----------------------"
+
+if ! $EXEC/src/apps/file/import_file x5*; then
+   echo ""
+   echo "import_file failed"
+   echo ""
+   exit 1
+fi
+
+sleep 1
+
+if ! $EXEC/src/apps/file/import_file x7*; then
+   echo ""
+   echo "import_file failed"
+   echo ""
+   exit 1
+fi
+
+sleep 1
+
+if ! $EXEC/src/apps/file/import_file x8*; then
+   echo ""
+   echo "import_file failed"
+   echo ""
+   exit 1
+fi
+
+sleep 1
+
+if ! $EXEC/src/apps/file/import_file x9*; then
+   echo ""
+   echo "import_file failed"
+   echo ""
+   exit 1
+fi
+
+sleep 2
+
+echo "------------------------------------"
+echo " sync with second archive again..."
+echo "------------------------------------"
+if ! $EXEC/src/apps/util/sync_archive /tmp/objectify_test/private2.obj; then
+   echo ""
+   echo "sync_archive failed"
+   echo ""
+   exit 1
+fi
+
+sleep 2
+
+
+echo "-----------------------------------------"
+echo " verify it won't do it the wrong way..."
+echo "-----------------------------------------"
+if $EXEC/src/apps/util/sync_archive /tmp/objectify_test/private3.obj /tmp/objectify_test/private2.obj; then
+   echo ""
+   echo "sync_archive failed"
+   echo ""
+   exit 1
+fi
+
+
+echo "------------------------------------"
+echo " sync with the third archive..."
+echo "------------------------------------"
+if ! $EXEC/src/apps/util/sync_archive /tmp/objectify_test/private2.obj /tmp/objectify_test/private3.obj; then
+   echo ""
+   echo "sync_archive failed"
+   echo ""
+   exit 1
+fi
+
+sleep 2
+
 
 echo ""
 echo "All tests passed!"
