@@ -36,8 +36,8 @@
 #      Salt Lake City, UT 84127-0511, USA.
 #
 #   $Author: jsedwards $
-#   $Date: 2009-08-13 06:05:50 -0600 (Thu, 13 Aug 2009) $
-#   $Revision: 4325 $
+#   $Date: 2009-09-20 13:04:12 -0600 (Sun, 20 Sep 2009) $
+#   $Revision: 4372 $
 #
 #   NOTE: Subversion does not support the Log keyword so I have removed the
 #   logs that were here when I was using CVS.  Use the "svn log" command to
@@ -104,9 +104,9 @@ echo "------------------"
 
 echo $OBJECTIFY_PRIVATE_PATH
 
-if ! $EXEC/src/apps/util/prep_disk; then
+if ! $EXEC/src/apps/util/prep_archive; then
    echo ""
-   echo "prep_disk failed"
+   echo "prep_archive failed"
    echo ""
    exit 1
 fi
